@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# __coconut_hash__ = 0xe779536
+# __coconut_hash__ = 0x65a1e180
 
-# Compiled with Coconut version 1.5.0-post_dev49 [Fish License]
+# Compiled with Coconut version 1.5.0-post_dev57 [Fish License]
 
 """
 Utilities for use across all of bbopt.
@@ -11,17 +11,28 @@ Utilities for use across all of bbopt.
 # Coconut Header: -------------------------------------------------------------
 
 from __future__ import print_function, absolute_import, unicode_literals, division
-import sys as _coconut_sys, os.path as _coconut_os_path
-_coconut_file_path = _coconut_os_path.dirname(_coconut_os_path.abspath(__file__))
+import sys as _coconut_sys, os as _coconut_os
+_coconut_file_dir = _coconut_os.path.dirname(_coconut_os.path.abspath(__file__))
 _coconut_cached_module = _coconut_sys.modules.get(str("__coconut__"))
-if _coconut_cached_module is not None and _coconut_os_path.dirname(_coconut_cached_module.__file__) != _coconut_file_path:
+if _coconut_cached_module is not None and _coconut_os.path.dirname(_coconut_cached_module.__file__) != _coconut_file_dir:
     del _coconut_sys.modules[str("__coconut__")]
-_coconut_sys.path.insert(0, _coconut_file_path)
+_coconut_sys.path.insert(0, _coconut_file_dir)
+_coconut_module_name = _coconut_os.path.splitext(_coconut_os.path.basename(_coconut_file_dir))[0]
+if _coconut_module_name and _coconut_module_name[0].isalpha() and all(c.isalpha() or c.isdigit() for c in _coconut_module_name) and "__init__.py" in _coconut_os.listdir(_coconut_file_dir):
+    _coconut_full_module_name = str(_coconut_module_name + ".__coconut__")
+    import __coconut__ as _coconut__coconut__
+    _coconut__coconut__.__name__ = _coconut_full_module_name
+    for _coconut_v in vars(_coconut__coconut__).values():
+        if getattr(_coconut_v, "__module__", None) == str("__coconut__"):
+            try:
+                _coconut_v.__module__ = _coconut_full_module_name
+            except AttributeError:
+                _coconut_vtype = type(_coconut_v)
+                _coconut_vtype.__module__ = _coconut_full_module_name
+    _coconut_sys.modules[_coconut_full_module_name] = _coconut__coconut__
 from __coconut__ import *
 from __coconut__ import _coconut_call_set_names, _coconut, _coconut_MatchError, _coconut_igetitem, _coconut_base_compose, _coconut_forward_compose, _coconut_back_compose, _coconut_forward_star_compose, _coconut_back_star_compose, _coconut_forward_dubstar_compose, _coconut_back_dubstar_compose, _coconut_pipe, _coconut_star_pipe, _coconut_dubstar_pipe, _coconut_back_pipe, _coconut_back_star_pipe, _coconut_back_dubstar_pipe, _coconut_none_pipe, _coconut_none_star_pipe, _coconut_none_dubstar_pipe, _coconut_bool_and, _coconut_bool_or, _coconut_none_coalesce, _coconut_minus, _coconut_map, _coconut_partial, _coconut_get_function_match_error, _coconut_base_pattern_func, _coconut_addpattern, _coconut_sentinel, _coconut_assert, _coconut_mark_as_match, _coconut_reiterable
-if _coconut_sys.version_info >= (3,):
-    _coconut_sys.path.pop(0)
-
+_coconut_sys.path.pop(0)
 # Compiled Coconut: -----------------------------------------------------------
 
 
@@ -43,7 +54,6 @@ import numpy as np
 from portalocker import Lock
 
 from bbopt import constants
-from bbopt.registry import backend_registry
 
 
 Num = (int, float)
@@ -250,51 +260,20 @@ def open_with_lock(fpath, mode="rb+", timeout=None, **kwargs):
                     pass
 
 
-def convert_match_errors(name, func):
+def convert_match_errors(func):
     """Re-raise MatchErrors as TypeErrors."""
     @wraps(func)
     def match_errors_converted_func(*args, **kwargs):
         try:
             return func(*args, **kwargs)
         except MatchError as err:
-            raise TypeError("arguments did not match call signature for function {_coconut_format_0}".format(_coconut_format_0=(name)))
+            func_name = getattr(func, "__qualname__", func.__name__)
+            _coconut_raise_from_0 = TypeError("arguments did not match call signature for function {_coconut_format_0}".format(_coconut_format_0=(func_name)))
+            _coconut_raise_from_0.__cause__ = err
+            raise _coconut_raise_from_0
     return match_errors_converted_func
 
 
 def printerr(*args):
     """Print to stderr."""
     print(*args, file=sys.stderr)
-
-
-@_coconut_mark_as_match
-def init_backend(*_coconut_match_args, **_coconut_match_kwargs):
-    """Create a backend object of the given name with the given data."""
-    _coconut_match_check_0 = False
-    _coconut_FunctionMatchError = _coconut_get_function_match_error()
-    if (_coconut.sum((_coconut.len(_coconut_match_args) > 0, "name" in _coconut_match_kwargs)) == 1) and (_coconut.sum((_coconut.len(_coconut_match_args) > 1, "examples" in _coconut_match_kwargs)) == 1) and (_coconut.sum((_coconut.len(_coconut_match_args) > 2, "params" in _coconut_match_kwargs)) == 1):
-        _coconut_match_temp_0 = _coconut_match_args[0] if _coconut.len(_coconut_match_args) > 0 else _coconut_match_kwargs.pop("name")
-        _coconut_match_temp_1 = _coconut_match_args[1] if _coconut.len(_coconut_match_args) > 1 else _coconut_match_kwargs.pop("examples")
-        _coconut_match_temp_2 = _coconut_match_args[2] if _coconut.len(_coconut_match_args) > 2 else _coconut_match_kwargs.pop("params")
-        args = _coconut_match_args[3:]
-        _coconut_match_temp_3 = _coconut_match_kwargs.pop("attempt_to_update_backend") if "attempt_to_update_backend" in _coconut_match_kwargs else None
-        name = _coconut_match_temp_0
-        examples = _coconut_match_temp_1
-        params = _coconut_match_temp_2
-        attempt_to_update_backend = _coconut_match_temp_3
-        options = _coconut_match_kwargs
-        _coconut_match_check_0 = True
-    if not _coconut_match_check_0:
-        raise _coconut_FunctionMatchError('match def init_backend(name, examples, params, *args, attempt_to_update_backend=None, **options):', _coconut_match_args)
-
-    backend_cls = backend_registry[name]
-    backend_examples = examples[:]
-    backend_params = params.copy()
-    if attempt_to_update_backend is not None and isinstance(attempt_to_update_backend, backend_cls):
-        updated_backend = attempt_to_update_backend.attempt_update(backend_examples, backend_params, *args, **options)
-        if updated_backend is True:
-            return attempt_to_update_backend
-        elif isinstance(updated_backend, backend_cls):
-            return updated_backend
-        else:
-            assert updated_backend is False, "invalid backend.attempt_update return value {_coconut_format_0} from {_coconut_format_1}".format(_coconut_format_0=(updated_backend), _coconut_format_1=(backend_cls))
-    return backend_cls(backend_examples, backend_params, *args, **options)
